@@ -1,3 +1,5 @@
+"""Script for testing."""
+
 import os
 import sys
 
@@ -15,5 +17,8 @@ for folder in os.listdir(path):
 
 @pytest.mark.parametrize("demo", demos)
 def test_demo(demo):
+    """Test demos."""
     demo_build = f"{path}/{demo}/_build"
-    assert os.system(f"mkdir -p {demo_build} && cd {demo_build} && cmake -DPython3_EXECUTABLE={sys.executable} .. && make && ./{demo}") == 0
+    command = f"""mkdir -p {demo_build} && cd {demo_build} && \
+                  cmake -DPython3_EXECUTABLE={sys.executable} .. && make && ./{demo}"""
+    assert os.system(command) == 0
