@@ -4,19 +4,29 @@
 
 import random
 
+import basix
 import numpy as np
 import pytest
-
-import basix
+from basix import CellType
 
 
-@pytest.mark.parametrize("cell", [basix.CellType.triangle, basix.CellType.tetrahedron,
-                                  basix.CellType.quadrilateral, basix.CellType.hexahedron])
-@pytest.mark.parametrize("element, degree, element_args", [
-    (basix.ElementFamily.P, 1, [basix.LagrangeVariant.gll_warped]),
-    (basix.ElementFamily.P, 3, [basix.LagrangeVariant.gll_warped]),
-    (basix.ElementFamily.N1E, 3, [])
-])
+@pytest.mark.parametrize(
+    "cell",
+    [
+        CellType.triangle,
+        CellType.tetrahedron,
+        CellType.quadrilateral,
+        CellType.hexahedron,
+    ],
+)
+@pytest.mark.parametrize(
+    "element, degree, element_args",
+    [
+        (basix.ElementFamily.P, 1, [basix.LagrangeVariant.gll_warped]),
+        (basix.ElementFamily.P, 3, [basix.LagrangeVariant.gll_warped]),
+        (basix.ElementFamily.N1E, 3, []),
+    ],
+)
 @pytest.mark.parametrize("block_size", [1, 2, 4])
 def test_dof_transformations(cell, element, degree, element_args, block_size):
     try:
@@ -24,18 +34,17 @@ def test_dof_transformations(cell, element, degree, element_args, block_size):
     except ImportError:
         pytest.skip("Numba must be installed to run this test.")
 
+    from basix import numba_helpers
     from numba.core import types
     from numba.typed import Dict
 
-    from basix import numba_helpers
-
     transform_functions = {
-        basix.CellType.triangle: numba_helpers.apply_dof_transformation_triangle,
-        basix.CellType.quadrilateral: numba_helpers.apply_dof_transformation_quadrilateral,
-        basix.CellType.tetrahedron: numba_helpers.apply_dof_transformation_tetrahedron,
-        basix.CellType.hexahedron: numba_helpers.apply_dof_transformation_hexahedron,
-        basix.CellType.prism: numba_helpers.apply_dof_transformation_prism,
-        basix.CellType.pyramid: numba_helpers.apply_dof_transformation_pyramid
+        CellType.triangle: numba_helpers.T_apply_triangle,
+        CellType.quadrilateral: numba_helpers.T_apply_quadrilateral,
+        CellType.tetrahedron: numba_helpers.T_apply_tetrahedron,
+        CellType.hexahedron: numba_helpers.T_apply_hexahedron,
+        CellType.prism: numba_helpers.T_apply_prism,
+        CellType.pyramid: numba_helpers.T_apply_pyramid,
     }
 
     random.seed(1337)
@@ -44,14 +53,16 @@ def test_dof_transformations(cell, element, degree, element_args, block_size):
     data = np.array(list(range(e.dim * block_size)), dtype=np.double)
 
     for i in range(10):
-        cell_info = random.randrange(2 ** 30)
+        cell_info = random.randrange(2**30)
 
         data1 = data.copy()
-        data1 = e.apply_dof_transformation(data1, block_size, cell_info)
+        e.T_apply(data1, block_size, cell_info)
         # Numba function does not use blocked data
         data2 = data.copy().reshape(e.dim, block_size)
         # Mapping lists to numba dictionaries
-        entity_transformations = Dict.empty(key_type=types.string, value_type=types.float64[:, :, :])
+        entity_transformations = Dict.empty(
+            key_type=types.string, value_type=types.float64[:, :, :]
+        )
         for i, transformation in e.entity_transformations().items():
             entity_transformations[i] = transformation
 
@@ -64,13 +75,23 @@ def test_dof_transformations(cell, element, degree, element_args, block_size):
         assert np.allclose(data1, data2)
 
 
-@pytest.mark.parametrize("cell", [basix.CellType.triangle, basix.CellType.tetrahedron,
-                                  basix.CellType.quadrilateral, basix.CellType.hexahedron])
-@pytest.mark.parametrize("element, degree, element_args", [
-    (basix.ElementFamily.P, 1, [basix.LagrangeVariant.gll_warped]),
-    (basix.ElementFamily.P, 3, [basix.LagrangeVariant.gll_warped]),
-    (basix.ElementFamily.N1E, 3, [])
-])
+@pytest.mark.parametrize(
+    "cell",
+    [
+        CellType.triangle,
+        CellType.tetrahedron,
+        CellType.quadrilateral,
+        CellType.hexahedron,
+    ],
+)
+@pytest.mark.parametrize(
+    "element, degree, element_args",
+    [
+        (basix.ElementFamily.P, 1, [basix.LagrangeVariant.gll_warped]),
+        (basix.ElementFamily.P, 3, [basix.LagrangeVariant.gll_warped]),
+        (basix.ElementFamily.N1E, 3, []),
+    ],
+)
 @pytest.mark.parametrize("block_size", [1, 2, 4])
 def test_dof_transformations_to_transpose(cell, element, degree, block_size, element_args):
     try:
@@ -78,18 +99,17 @@ def test_dof_transformations_to_transpose(cell, element, degree, block_size, ele
     except ImportError:
         pytest.skip("Numba must be installed to run this test.")
 
+    from basix import numba_helpers
     from numba.core import types
     from numba.typed import Dict
 
-    from basix import numba_helpers
-
     transform_functions = {
-        basix.CellType.triangle: numba_helpers.apply_dof_transformation_to_transpose_triangle,
-        basix.CellType.quadrilateral: numba_helpers.apply_dof_transformation_to_transpose_quadrilateral,
-        basix.CellType.tetrahedron: numba_helpers.apply_dof_transformation_to_transpose_tetrahedron,
-        basix.CellType.hexahedron: numba_helpers.apply_dof_transformation_to_transpose_hexahedron,
-        basix.CellType.prism: numba_helpers.apply_dof_transformation_to_transpose_prism,
-        basix.CellType.pyramid: numba_helpers.apply_dof_transformation_to_transpose_pyramid
+        CellType.triangle: numba_helpers.Tt_apply_right_triangle,
+        CellType.quadrilateral: numba_helpers.Tt_apply_right_quadrilateral,
+        CellType.tetrahedron: numba_helpers.Tt_apply_right_tetrahedron,
+        CellType.hexahedron: numba_helpers.Tt_apply_right_hexahedron,
+        CellType.prism: numba_helpers.Tt_apply_right_prism,
+        CellType.pyramid: numba_helpers.Tt_apply_right_pyramid,
     }
 
     random.seed(1337)
@@ -98,14 +118,16 @@ def test_dof_transformations_to_transpose(cell, element, degree, block_size, ele
     data = np.array(list(range(e.dim * block_size)), dtype=np.double)
 
     for i in range(10):
-        cell_info = random.randrange(2 ** 30)
+        cell_info = random.randrange(2**30)
 
         data1 = data.copy()
-        data1 = e.apply_dof_transformation_to_transpose(data1, block_size, cell_info)
+        e.Tt_apply_right(data1, block_size, cell_info)
         # Numba function does not use blocked data
         data2 = data.copy().reshape(block_size, e.dim)
         # Mapping lists to numba dictionaries
-        entity_transformations = Dict.empty(key_type=types.string, value_type=types.float64[:, :, :])
+        entity_transformations = Dict.empty(
+            key_type=types.string, value_type=types.float64[:, :, :]
+        )
         for i, transformation in e.entity_transformations().items():
             entity_transformations[i] = transformation
 
