@@ -3,21 +3,26 @@
 # SPDX-License-Identifier: MIT
 
 import re
-
-import pkg_resources
-import pytest
+from importlib.metadata import version
 
 import basix
+import pytest
 
 
 def is_canonical(version):
     """Check version number is canonical according to PEP0440
 
     From https://peps.python.org/pep-0440/#appendix-b-parsing-version-strings-with-regular-expressions"""
-    return re.match(r'^([1-9][0-9]*!)?(0|[1-9][0-9]*)(\.(0|[1-9][0-9]*))*((a|b|rc)(0|[1-9][0-9]*))?(\.post(0|[1-9][0-9]*))?(\.dev(0|[1-9][0-9]*))?$', version) is not None  # noqa: E501
+    return (
+        re.match(
+            r"^([1-9][0-9]*!)?(0|[1-9][0-9]*)(\.(0|[1-9][0-9]*))*((a|b|rc)(0|[1-9][0-9]*))?(\.post(0|[1-9][0-9]*))?(\.dev(0|[1-9][0-9]*))?$",
+            version,
+        )
+        is not None
+    )
 
 
-def test_version(python_version=pkg_resources.get_distribution("fenics-basix").version, cpp_version=basix.__version__):
+def test_version(python_version=version("fenics-basix"), cpp_version=basix.__version__):
     assert is_canonical(python_version)
 
     # Strip Python-specific versioning (dev, post) and compare with C++
@@ -26,8 +31,10 @@ def test_version(python_version=pkg_resources.get_distribution("fenics-basix").v
     stripped_version = stripped_version.replace("dev", "")
     if stripped_version != cpp_version:
         raise RuntimeError(
-            f"The version numbers of the Python ({pkg_resources.get_distribution('fenics-basix').version} "
-            + f"-> {stripped_version}) and pybind11/C++ ({basix.__version__}) libraries does not match")
+            f"The version numbers of the Python ({python_version} "
+            f"-> {stripped_version}) and nanobind/C++ ({basix.__version__}) "
+            " libraries do not match."
+        )
 
 
 def test_test_version_logic():
