@@ -2,11 +2,10 @@
 # FEniCS Project
 # SPDX-License-Identifier: MIT
 
+import basix
 import numpy as np
 import pytest
 
-import basix
-
 from .utils import parametrize_over_elements
 
 
@@ -22,7 +21,11 @@ def tensor_product(*data):
 
 @parametrize_over_elements(5)
 def test_orthonormal(cell_type, degree, element_type, element_args):
-    if element_type == basix.ElementFamily.iso and cell_type == basix.CellType.hexahedron and degree > 3:
+    if (
+        element_type == basix.ElementFamily.iso
+        and cell_type == basix.CellType.hexahedron
+        and degree > 3
+    ):
         pytest.skip()  # Skip slow test
 
     element = basix.create_element(element_type, cell_type, degree, *element_args)
